package org.jeecg.modules.system.app.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

public interface StatisticsMapper {
    /**
     * <p>管理端首页获取商品销量排行</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    @MapKey("ranking")
    List<Map<String, Object>> findByShopSum(@Param("type")int type, @Param("orgCode")String orgCode);

    /**
     * <p>管理端首页获取部门售额排行</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    @MapKey("ranking")
    List<Map<String, Object>> findByDeptSum(@Param("type")int type,@Param("orgCode")String orgCode);

    /**
     * <p>首页统计</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    Map<String, Object> findIndexStatistics(@Param("orgCode")String orgCode);

    /**
     * <p>本月销售额趋势图</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findMonthSaleTrend(@Param("orgCode")String orgCode);

    /**
     * <p>分页查询店铺资金总览</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findShopAccountOverview(@Param("page")Page<Map<String, Object>> page, @Param("name")String name);

    /**
     * <p>查询店铺资金总览-门店统计</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> findShopAccountOverviewDept(@Param("orgCode")String orgCode);

    /**
     * <p>分页查询店铺资金总览-门店</p>
     * @author SheepHy
     * @param 参数描述，参数为类则包含{@link Object}
     * @return 返回值描述，如无返回值则为void 返回值为类则包含{@link object}
     *
     */
    List<Map<String, Object>> selectFundChanges(@Param("page")Page<Map<String, Object>> page,
                                                @Param("orgCode")String orgCode,
                                                @Param("incomeExpenseType")String incomeExpenseType,
                                                @Param("changeReason")String changeReason,
                                                @Param("amountType")String amountType);
}
